notmain

package module
v0.1.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 5, 2024 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Overview

Package notmain Package path implements utility routines for manipulating slash-separated paths.

The path package should only be used for paths separated by forward slashes, such as the paths in URLs. This package does not deal with Windows paths with drive letters or backslashes; to manipulate operating system paths, use the path/filepath package.

Index

Constants

const (
	EOF = -(iota + 1)
	Ident
	Int
	Float
	Char
)

The result of Scan is one of these tokens or a Unicode character.

const (
	MaxRune         = '\U0010FFFF' // maximum valid Unicode code point.
	ReplacementChar = '\uFFFD'     // represents invalid code points.
	MaxASCII        = '\u007F'     // maximum ASCII value.
	MaxLatin1       = '\u00FF'     // maximum Latin-1 value.
)

Variables

This section is empty.

Functions

func Exit added in v0.1.8

func Exit(code int)

Exit causes the current program to exit with the given status code. Conventionally, code zero indicates success, non-zero an error. The program terminates immediately; deferred functions are not run.

For portability, the status code should be in the range [0, 125].

func LolMain

func LolMain()

func Sort added in v0.1.8

func Sort(data string)

Sort sorts data in ascending order as determined by the Less method. It makes one call to data.Len to determine n and O(n*log(n)) calls to data.Less and data.Swap. The sort is not guaranteed to be stable.

func Sqrt added in v0.1.8

func Sqrt(x float64) float64

Sqrt returns the square root of x.

Special cases are:

Sqrt(+Inf) = +Inf
Sqrt(±0) = ±0
Sqrt(x < 0) = NaN
Sqrt(NaN) = NaN

Types

type Op added in v0.1.8

type Op uint8

An Op is a single regular expression operator.

const (
	OpNoMatch      Op = 1 + iota // matches no strings
	OpEmptyMatch                 // matches empty string
	OpLiteral                    // matches Runes sequence
	OpCharClass                  // matches Runes interpreted as range pair list
	OpAnyCharNotNL               // matches any character except newline
)

type Reader added in v0.1.8

type Reader struct {
	// contains filtered or unexported fields
}

A Reader serves content from a ZIP archive.

Directories

Path Synopsis
Gofmt formats Go programsssss.
Gofmt formats Go programsssss.
cmd
op command

Jump to