Documentation
¶
Overview ¶
Package notmain Package path implements utility routines for manipulating slash-separated paths.
The path package should only be used for paths separated by forward slashes, such as the paths in URLs. This package does not deal with Windows paths with drive letters or backslashes; to manipulate operating system paths, use the path/filepath package.
Index ¶
Constants ¶
const ( EOF = -(iota + 1) Ident Int Float Char )
The result of Scan is one of these tokens or a Unicode character.
const ( MaxRune = '\U0010FFFF' // maximum valid Unicode code point. ReplacementChar = '\uFFFD' // represents invalid code points. MaxASCII = '\u007F' // maximum ASCII value. MaxLatin1 = '\u00FF' // maximum Latin-1 value. )
Variables ¶
This section is empty.
Functions ¶
func Exit ¶ added in v0.1.8
func Exit(code int)
Exit causes the current program to exit with the given status code. Conventionally, code zero indicates success, non-zero an error. The program terminates immediately; deferred functions are not run.
For portability, the status code should be in the range [0, 125].